Package: rextor
Title: Prepare 'WEXTOR' Data
Version: 1.1.0
Depends: R (>= 4.1.0)
Authors@R: c(person("Annika Tave", "Overlander", role = c("aut","cre"), email = "annika-tave.overlander@uni.kn",
             comment = c(ORCID = "0009-0006-8373-4086")),
            person("Ulf-Dietrich", "Reips", role = c("ths", "cph"), 
              comment = c(ORCID = "0000-0002-1566-4745")))
Description: Facilitate data preparation for data collected on 'WEXTOR' <https://wextor.eu>, created by Reips and Neuhaus (2002) <doi:10.3758/bf03195449>. Perform plausibility and other checks and make use of cool color palettes and themes for data visualization.
License: GPL (>= 3)
Date: 2026-05-06
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: dplyr, readr, ggplot2
Suggests: knitr, rmarkdown, rlang, scales, tibble
VignetteBuilder: knitr
URL: https://iscience-kn.github.io/rextor/
NeedsCompilation: no
Packaged: 2026-05-17 15:51:44 UTC; PCUser
Author: Annika Tave Overlander [aut, cre] (ORCID:
    <https://orcid.org/0009-0006-8373-4086>),
  Ulf-Dietrich Reips [ths, cph] (ORCID:
    <https://orcid.org/0000-0002-1566-4745>)
Maintainer: Annika Tave Overlander <annika-tave.overlander@uni.kn>
Repository: CRAN
Date/Publication: 2026-05-21 09:20:07 UTC
Built: R 4.6.0; ; 2026-05-25 04:01:30 UTC; unix
