# Generated by roxygen2: do not edit by hand

S3method(ggplot_add,dino_scale)
export(ask_rex)
export(check_ok)
export(getmode)
export(getperc)
export(informed_consent)
export(ip_check)
export(namepref)
export(namepref0)
export(path_to_file)
export(plausicheck)
export(read_WEXTOR)
export(removepref)
export(scale_rextor)
export(serious_check)
export(sess_length_check)
export(theme_wob)
import(dplyr)
import(ggplot2)
import(readr)
importFrom(stats,na.omit)
importFrom(stats,quantile)
