#' BiFiX - Big Five raw data
#'
#' Raw data from the BiFiX study (submitted for publication in BRM)
#'
#' @name BiFiX_data_raw
#' @format A data frame with 760 rows and 81 columns:
#' \describe{
#'   \item{$validation_var}{validation variable}
#'   \item{.wx.1.id}{ID}
#'   \item{.wx.3.experimental_condition}{Experimental condition}
#'   \item{big_...}{Big Five items (A - Agreeableness, C - Conscientiousness, 
#'    E - Extraversion, N - Neuroticism, O - Openness)}
#'   ...
#' }
#' @source <https://github.com/iscience-kn/BiFiX>
NULL